@@ -11,7 +11,7 @@ class SQLAlchemyMonitor(BaseMonitor):
     last_statement_started_at: Optional[float]
     total_db_time: float
     engine: engine.Engine
-    instance_setup_cb: Optional[Callable[["SQLAlchemyMonitor"], None]]
+    instance_setup_cb: Optional[Callable]
 
     def __init__(self):
         self.statement_count = 0
@@ -22,13 +22,15 @@ class SQLAlchemyMonitor(BaseMonitor):
         self.last_statement_started_at = time.time()
 
     def handle_after_event(self, conn, cursor, statement, parameters, context, executemany):
+        assert self.last_statement_started_at
         exec_time = time.time() - self.last_statement_started_at
         self.last_statement_started_at = None
         self.total_db_time += exec_time
         self.statement_count += 1
 
     def setup(self):
-        self.instance_setup_cb()
+        if self.instance_setup_cb is not None:
+            self.instance_setup_cb()
         event.listen(self.engine, "before_cursor_execute", self.handle_before_event)
         event.listen(self.engine, "after_cursor_execute", self.handle_after_event)
 
